@@ -21,7 +21,7 @@ use nix::{
     sys::{
         socket::{
             bind, recvfrom, sendto, setsockopt, socket, sockopt,
-            AddressFamily, MsgFlags, SockAddr, SockFlag, SockType, UnixAddr,
+            AddressFamily, MsgFlags, SockFlag, SockType, UnixAddr,
         },
         time::{TimeVal, TimeValLike},
     },
@@ -29,6 +29,8 @@ use nix::{
 };
 use std::os::unix::io::RawFd;
 
+pub use nix::sys::socket::SockAddr;
+
 /// Wrap raw data
 pub struct UauSock {
     fd: RawFd,
@@ -182,7 +184,7 @@ impl UauSock {
 
     /// Try to convert a user-given addr to SockAddr
     pub fn addr_to_sock(addr: &[u8]) -> Result<SockAddr> {
-        SockAddr::Unix(UnixAddr::new_abstract(addr).c(d!())?)
+        UnixAddr::new_abstract(addr).c(d!()).map(SockAddr::Unix)
     }
 }
 
